@@ -1,4 +1,5 @@
 #![allow(
+    dead_code,
     clippy::precedence,
     clippy::type_complexity,
     clippy::float_cmp,
@@ -7,9 +8,6 @@
     clippy::many_single_char_names,
     clippy::manual_range_contains
 )]
-#![allow(dead_code)]
-
-extern crate fundsp;
 
 use fundsp::audiounit::*;
 use fundsp::hacker::*;
@@ -70,14 +68,6 @@ fn check_wave_filter(input: &Wave64, mut node: impl AudioUnit64) {
     }
 }
 
-/// New nodes can be defined with the following return signature.
-/// Declaring the full arity in the signature enables use of the node
-/// in further combinations, as does the full type name.
-/// Signatures with generic number of channels can be challenging to write.
-fn split_quad() -> An<impl AudioNode<Sample = f64, Inputs = U1, Outputs = U4>> {
-    pass() ^ pass() ^ pass() ^ pass()
-}
-
 /// Attempt to test two nodes for equality.
 fn is_equal<X, Y>(rnd: &mut AttoRand, x: &mut An<X>, y: &mut An<Y>) -> bool
 where
@@ -97,6 +87,27 @@ where
     true
 }
 
+/// Attempt to test two stereo filters for equality.
+fn is_equal_unit<X, Y>(rnd: &mut AttoRand, x: &mut X, y: &mut Y) -> bool
+where
+    X: AudioUnit64,
+    Y: AudioUnit64,
+{
+    assert!(2 == y.inputs() && x.inputs() == 2);
+    assert!(x.outputs() == 2 && 2 == y.outputs());
+
+    for _ in 0..1000 {
+        let input0 = (rnd.get() & 0xf) as f64;
+        let input1 = (rnd.get() & 0xf) as f64;
+        let output_x = x.filter_stereo(input0, input1);
+        let output_y = y.filter_stereo(input0, input1);
+        if output_x != output_y {
+            return false;
+        }
+    }
+    true
+}
+
 /// Check that the outputs of a node are all unique.
 fn outputs_diverge<X>(rnd: &mut AttoRand, x: &mut An<X>) -> bool
 where
@@ -178,7 +189,7 @@ fn test_basic() {
     check_wave(
         dc((110.0, 220.0, 440.0, 880.0)) >> multipass() >> (sink() | -sine() | sink() | sine()),
     );
-    // TODO. The next test fails with declicker present and dsf_square(0.99), why?
+    // TODO. The next test fails with declicker present and dsf_square_r(0.99), why?
     // It passes if tolerance is increased to 1.0e-8. Is this acceptable because of
     // declicker process vs. tick - the phase accumulation is slightly different?
     check_wave(dc((110.0, 220.0)) >> declick_s(0.1) + pass() >> (saw() ^ dsf_square_r(0.9)));
@@ -218,6 +229,14 @@ fn test_basic() {
     sequencer.add64(0.6, 0.7, 0.01, 0.0, Box::new(noise() | mls()));
     check_wave(sequencer);
 
+    let mut net = Net64::new(0, 2);
+    let id = net.add(Box::new(
+        noise() >> moog_hz(1500.0, 0.8) | noise() >> moog_hz(500.0, 0.4),
+    ));
+    net.connect_output(id, 0, 0);
+    net.connect_output(id, 1, 1);
+    check_wave(net);
+
     check_wave((noise() | envelope(|t| spline_noise(1, t * 10.0))) >> panner());
     check_wave(noise() >> monitor(Meter::Sample, 0) >> pan(-0.5) | timer(1));
     check_wave(tag(0, 5.0) >> lfo2(|t, x| t * x) | tag(1, 1.0));
@@ -258,7 +277,6 @@ fn test_basic() {
     let x = 3.0;
     let y = -4.0;
     let z = 5.0;
-    assert!(is_equal(&mut rnd, &mut split_quad(), &mut split_quad()));
 
     // Test bus vs. branch equivalence.
     assert!(is_equal(
@@ -277,6 +295,50 @@ fn test_basic() {
         &mut (add(z) & mul(y) >> sub(x) & add(w) >> mul(y) & sub(x) >> add(z))
     ));
 
+    // Nodes vs. networks.
+    let mut pass_through = pass() | pass();
+    let mut pass_through_net = Net64::new(2, 2);
+    pass_through_net.join(edge(Port::Global(0), Port::Global(0)));
+    pass_through_net.join(edge(Port::Global(1), Port::Global(1)));
+    assert!(is_equal_unit(
+        &mut rnd,
+        &mut pass_through,
+        &mut pass_through_net
+    ));
+
+    let mut swap_through = swap();
+    let mut swap_through_net = Net64::new(2, 2);
+    swap_through_net.join(edge(Port::Global(0), Port::Global(1)));
+    swap_through_net.join(edge(Port::Global(1), Port::Global(0)));
+    assert!(is_equal_unit(
+        &mut rnd,
+        &mut swap_through,
+        &mut swap_through_net
+    ));
+
+    let mut multiply_2_3 = mul(2.0) | mul(3.0);
+    let mut multiply_net = Net64::new(2, 2);
+    multiply_net.add(Box::new(mul(2.0)));
+    multiply_net.add(Box::new(mul(3.0)));
+    multiply_net.connect_input(0, 0, 0);
+    multiply_net.connect_input(1, 1, 0);
+    multiply_net.connect_output(0, 0, 0);
+    multiply_net.connect_output(1, 0, 1);
+    assert!(is_equal_unit(
+        &mut rnd,
+        &mut multiply_2_3,
+        &mut multiply_net
+    ));
+
+    let mut add_2_3 = add((2.0, 3.0));
+    let mut add_net = Net64::new(2, 2);
+    add_net.add(Box::new(add((2.0, 3.0))));
+    add_net.add(Box::new(multipass::<U2>()));
+    add_net.pipe_input(0);
+    add_net.pipe(0, 1);
+    add_net.pipe_output(1);
+    assert!(is_equal_unit(&mut rnd, &mut add_2_3, &mut add_net));
+
     // Test multichannel constants vs. stacked constants.
     assert!(is_equal(
         &mut rnd,
